==> react-lds-8.7.0.tgz: package/es/components/Icon/Icon.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.regexp.replace";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import IconSVG from './IconSVG';

var iconClass = function iconClass(sprite, icon) {
  return icon.replace(/_/g, '-');
};

var Icon = function Icon(props) {
  var background = props.background,
      className = props.className,
      div = props.div,
      icon = props.icon,
      size = props.size,
      sprite = props.sprite,
      svgClassName = props.svgClassName,
      title = props.title,
      rest = _objectWithoutProperties(props, ["background", "className", "div", "icon", "size", "sprite", "svgClassName", "title"]);

  var backgroundClass = !background ? "slds-icon-".concat(sprite, "-").concat(iconClass(sprite, icon)) : "slds-icon-".concat(background);
  var sldsClasses = [{
    'slds-icon_container': true
  }, {
    'slds-icon_container_circle': sprite === 'action'
  }, _defineProperty({}, "".concat(backgroundClass), background !== false), className];
  var WrapperElement = div ? 'div' : 'span';
  return React.createElement(WrapperElement, _extends({}, rest, {
    className: cx(sldsClasses),
    title: title
  }), React.createElement(IconSVG, {
    className: svgClassName,
    icon: icon,
    size: size,
    sprite: sprite
  }), React.createElement("span", {
    className: "slds-assistive-text"
  }, title));
};

Icon.defaultProps = {
  background: null,
  className: null,
  div: false,
  size: null,
  svgClassName: null,
  title: null
};
Icon.propTypes = process.env.NODE_ENV !== "production" ? {
  /** Set this if you want to override the default background class. set to false to not set a background */
  background: PropTypes.oneOfType([PropTypes.string, PropTypes.bool]),

  /** class name */
  className: PropTypes.string,

  /** <div>-container instead of a <span>-container */
  div: PropTypes.bool,

  /** Name of the icon */
  icon: PropTypes.string.isRequired,

  /** Size */
  size: PropTypes.oneOf(['xx-small', 'x-small', 'small', 'medium', 'large']),

  /** Name of the sprite containing the icon */
  sprite: PropTypes.oneOf(['action', 'custom', 'doctype', 'standard', 'utility']).isRequired,

  /** ClassName that will be handed over to the <svg /> */
  svgClassName: PropTypes.string,

  /** Descriptive Title */
  title: PropTypes.string
} : {};
export default Icon;

==> react-lds-9.1.0.tgz: package/es/components/Icon/Icon.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.regexp.exec";
import "core-js/modules/es.string.replace";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import IconSVG from './IconSVG';

var iconClass = function iconClass(sprite, icon) {
  return icon.replace(/_/g, '-');
};

var Icon = function Icon(props) {
  var background = props.background,
      className = props.className,
      div = props.div,
      icon = props.icon,
      size = props.size,
      sprite = props.sprite,
      svgClassName = props.svgClassName,
      title = props.title,
      rest = _objectWithoutProperties(props, ["background", "className", "div", "icon", "size", "sprite", "svgClassName", "title"]);

  var backgroundClass = !background ? "slds-icon-".concat(sprite, "-").concat(iconClass(sprite, icon)) : "slds-icon-".concat(background);
  var sldsClasses = [{
    'slds-icon_container': true
  }, {
    'slds-icon_container_circle': sprite === 'action'
  }, _defineProperty({}, "".concat(backgroundClass), background !== false), className];
  var WrapperElement = div ? 'div' : 'span';
  return React.createElement(WrapperElement, _extends({}, rest, {
    className: cx(sldsClasses),
    title: title
  }), React.createElement(IconSVG, {
    className: svgClassName,
    icon: icon,
    size: size,
    sprite: sprite
  }), React.createElement("span", {
    className: "slds-assistive-text"
  }, title));
};

Icon.defaultProps = {
  background: null,
  className: null,
  div: false,
  size: null,
  svgClassName: null,
  title: null
};
Icon.propTypes = process.env.NODE_ENV !== "production" ? {
  /** Set this if you want to override the default background class. set to false to not set a background */
  background: PropTypes.oneOfType([PropTypes.string, PropTypes.bool]),

  /** class name */
  className: PropTypes.string,

  /** <div>-container instead of a <span>-container */
  div: PropTypes.bool,

  /** Name of the icon */
  icon: PropTypes.string.isRequired,

  /** Size */
  size: PropTypes.oneOf(['xx-small', 'x-small', 'small', 'medium', 'large']),

  /** Name of the sprite containing the icon */
  sprite: PropTypes.oneOf(['action', 'custom', 'doctype', 'standard', 'utility']).isRequired,

  /** ClassName that will be handed over to the <svg /> */
  svgClassName: PropTypes.string,

  /** Descriptive Title */
  title: PropTypes.string
} : {};
export default Icon;
